大话西游之月光宝盒 (豆瓣)
Description: 大话西游之月光宝盒电影简介和剧情介绍,大话西游之月光宝盒影评、图片、预告片、影讯、论坛、在线购票
Keywords: 大话西游之月光宝盒,西遊記第壹佰零壹回之月光寶盒,大话西游之月光宝盒影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.45豆瓣电影Top250

# 大话西游之月光宝盒 西遊記第壹佰零壹回之月光寶盒 (1995)

导演: 刘镇伟
编剧: 刘镇伟 / 吴承恩
主演: 周星驰 / 吴孟达 / 罗家英 / 蓝洁瑛 / 莫文蔚 / 江约诚 / 陆树铭 / 刘镇伟 / 朱茵 / 李健仁
类型: 喜剧 / 爱情 / 奇幻 / 古装
制片国家/地区: 中国香港 / 中国大陆
语言: 粤语 / 汉语普通话
上映日期: 2014-10-24(中国大陆) / 1995-01-21(中国香港)
片长: 88分钟
又名: 西游记101回月光宝盒 / 齐天大圣东游记 / 大话东游之一 / A Chinese Odyssey Part One - Pandora's Box
IMDb: tt0112778
豆瓣评分
引用
9.0
1164392人评价
5星
60.1%
4星
31.8%
3星
7.3%
2星
0.5%
1星
0.2%
好于 99% 喜剧片
好于 99% 爱情片
想看 看过
评价:
推荐

## 大话西游之月光宝盒的剧情简介 · · · · · ·

孙悟空（周星驰）护送唐三藏（罗家英）去西天取经路上，与牛魔王合谋欲杀害唐三藏，并偷走了月光宝盒，此举使观音萌生将其铲除心思，经唐三藏请求，孙悟空被判五百年后重新投胎做人赎其罪孽。
五百年后孙悟空化身强盗头头至尊宝。当遇见预谋吃唐僧肉的妖怪姐妹蜘蛛精春三十娘（蓝洁瑛）和白骨精白晶晶（莫文蔚）时，因为五百年前孙悟空曾与白晶晶有过一段恋情，至尊宝与她一见钟情，但因菩提老祖将二人妖怪身份相告，至尊宝仍带领众强盗开始与二妖展开周旋，过程中，白晶晶为救至尊宝打伤春三十娘，自己也中毒受伤，为了救白晶晶，至尊宝去找春三十娘，遭白晶晶误会，绝望自杀，至尊宝开始用月光宝盒以期使时光倒流。 ©豆瓣

## 大话西游之月光宝盒的演职员 · · · · · · ( 全部 26 )

- 刘镇伟 导演
- 周星驰 饰 至尊宝/孙悟空
- 吴孟达 演员
- 罗家英 演员
- 蓝洁瑛 饰 春三十娘
- 莫文蔚 演员

## 大话西游之月光宝盒的视频和图片 · · · · · · ( 预告片2 | 添加视频评论 | 图片709 · 添加 )

## 大话西游之月光宝盒的获奖情况 · · · · · · ( 全部 )

- 第15届香港电影金像奖
- 最佳编剧(提名)
- 刘镇伟

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  泰坦尼克号

  倩女幽魂

  大话西游之大圣娶亲

  重庆森林

  甜蜜蜜

  剪刀手爱德华

  喜剧之王

  天使爱美丽

  本杰明·巴顿奇事

我要写短评

## 大话西游之月光宝盒的短评 · · · · · · ( 全部 131028 条 )

热门 / 最新 / 好友

### 2098 有用 Lan~die 看过 2006-10-07 10:48:43

对我们这代人影响最大的电影。寓言故事已然存在，不可避免。世界是巨大的枷锁，你不得不重复自己或是别人的生活。 台词：你看那个人的背影好奇怪，他好像条狗啊。

### 2037 有用 罗弘霉素 看过 2010-07-26 18:35:55

一遍烂，两遍笑，三遍哭。盘丝大仙给了三颗痣，斧头帮主翻过照妖镜，看着镜中的猴子，此处的配乐足够震撼

### 153 有用 Shudoku 看过 2013-06-20 05:42:55

神马乱七八糟的。。。过度被神化了的作品。80后们的爱情灵感居然是被这样混乱无厘头的一部剧都激发出来的。。。囧

### 1222 有用 hammo 看过 2016-07-26 16:32:41

那年的蓝洁瑛怎么那么好看 好看到我眼里完全没有莫女神。 18.11.03更新 今天瑛姑过世了，这一辈子太苦，但愿天堂里有属于你的月光宝盒。

### 1497 有用 托尼·王大拿 看过 2009-07-31 03:19:50

这才叫旷古烁今。

> 更多短评 131028条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 大话西游之月光宝盒的影评 · · · · · · ( 全部 1015 条 )

热门 / 最新 / 好友
Autorun 2007-08-29 17:10:46

## 假设：我们只能爱一个人

但凡和我接触的稍微深入一点，谈过一些理想情操精神生活之类的朋友，我都会像祥林嫂一样不厌其烦并且冷不丁的问人家一句，“你觉得大话西游里面，至尊宝爱的是谁？” 我不是欠揍，我是真的没想明白。 答案众说纷纭。不过也不外乎三种：A.紫霞，B.晶晶，C.说不清楚。当然，不... (展开)
4093 286 548回应 收起
Woohoo 2009-02-19 23:25:18

## 且看他，忍把浮名,换了浅斟低唱

看过一个视频，周星驰作客汕大时候，主持人问过他一个问题：有没有在爱情上感到沧桑？ 周星驰：我在爱情上面，大家都知道了，经过了很多“生生死死”话锋一转，就这样，对不起，真的不能讲 可以想象这个人对自己的隐私保留到近乎吝啬的程度了。他的爱情是个谜。最广为人知的... (展开)
1062 75 101回应 收起
黑猫 2007-04-23 19:11:27

## 月光宝盒：爱上已婚男子的悲哀

许是自己年纪大了，看了这些个乱七八糟的事情多了，渐渐的~什么都明白了。 看至尊宝和白晶晶、紫霞的爱情心生伤感。宿命里就是有那么多的无可奈何，真以为可以和一个人厮守到老的时候，却又冒出另一个上天安排的姻缘。 仿佛老天爷就是要玩你，玩死你。 男人发誓的时候常常说... (展开)
585 22 55回应 收起
北星云 2008-11-20 11:44:43

## 你爱的是妖还是仙？

这篇影评可能有剧透

我一直不明白，至尊宝为什么会爱紫霞多过白晶晶。 问了朋友们，绝大多数都说：爱紫霞。 为什么？ 答：一个是妖，一个是仙，我是人当然爱仙女，我怎么会爱一个白骨精？ 我——还是——不——明——白。 若我是至尊宝，一定无法忘记初见白晶晶的惊艳。 若我是至尊宝，一定无法忘... (展开)
187 12 51回应 收起
沉默の玩 2006-05-16 14:53:46

## 我们的隔绝

《大话西游》其实讲了一个伤感的故事。一个男人爱上一个女人，但被分开了。为了要回自己的女人，他利用另一个女人。达到目的之后，才发现自己爱上了这一个。可是为时已晚，大家分道扬镳，各自黯然上路。 《大话西游》提出的问题是，我们并不知道自己真正要什么。为什么... (展开)
152 13 33回应 收起
新桥妖妖 2017-07-15 10:31:04

## 一生所爱又如何

至尊宝有一句被世人传滥了的情话：曾经有一份真诚的爱情放在我面前，我没有珍惜，等我失去的时候我才后悔莫及，人世间最痛苦的事莫过于此。 如果上天能够给我一个再来一次的机会，我会对那个女孩子说三个字:我爱你。如果非要在这份爱上加上一个期限，我希望是……一万年！ 对面... (展开)
89 3 8回应 收起
暖言巷陌 2010-04-30 11:03:47

## 天上风筝在天上飞

【做痛苦的至尊宝还是做一头幸福的猪】 至尊宝一直搞不清楚。 他是孙悟空还是至尊宝，抑或只是孙悟空的一场黄粱梦。 他穿梭了时空，却看不清命运。 面对无法收拾的爱情残局，他只能离开。 “你看那个人，好奇怪哟，象一条狗。” 有人说爱情是指数函数，就是e的x次方。不管对... (展开)
95 5 16回应 收起
momo 2017-03-29 11:40:30

## 大话西游之月光宝盒

《大话西游之月光宝盒》是周星驰彩星电影公司1994年制作和出品的一部经典的无厘头搞笑片，改编依据是吴承恩所撰写的神怪小说《西游记》，该片是《大话西游》系列的第一部，由刘镇伟导演，技安编剧，周星驰制作，周星驰、莫文蔚、吴孟达、蓝洁瑛等人主演。 该片主要讲述了唐僧... (展开)
77 11 2回应 收起

> 更多影评 1015篇

添加新讨论

## 讨论区 · · · · · ·

烂片一部，没有之一。 | 来自著名导演刘信达 | 11 回应 | 2022-11-19 07:00:02
内地对周星驰的崇拜只因为对香港影视的无知 | 来自王奋斗 | 6 回应 | 2022-11-19 06:55:45
00后，单纯想问一下这部片到底好在哪里，自己看不... | 来自万物理论. | 1 回应 | 2022-11-18 15:45:21
大烂片 | 来自汪直 | 40 回应 | 2022-11-11 14:42:55
情怀式烂片 | 来自荸荠和菱角 | 84 回应 | 2022-11-06 01:08:55

> 去这部影片的讨论区（全部297条）

## 关于《大话西游之月光宝盒》的问题 · · · · · · ( 全部18个 )

- 至尊宝和白晶晶做爱的时候，为什么白晶晶突然哭了？ 4人回答
- 为什么至尊宝竟然爱上了白晶晶？ 12人回答

> 全部18个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 1905电影网 免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 文艺女王必修课「华语篇」 (不良生)
- 80末出生的人是这样成长的 (沉歌)
- 179部经典港片 (德拉库拉拉)
- 100部爱情电影 经典的回味 (isay)

## 谁在看这部电影 · · · · · ·

- 尛惢乀
  刚刚 看过
- Victor
  1分钟前 看过
- 勇敢叮当猫
  2分钟前 看过

2380590人看过 / 124754人想看

订阅大话西游之月光宝盒的评论:
feed: rss 2.0